==> nextcloud-app-calendar-1%3A6.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/es_AR.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "La dirección de E Mail proporcionada no es valida",
    "Hello," : "Hola,",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "Location:" : "Ubicación:",
    "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
    "Previous day" : "Día previo",
    "Previous week" : "Semana previa",
    "Previous month" : "Mes previo",
    "Next day" : "Proximo día",
    "Next week" : "Proxima semana",
    "Next month" : "Proximo mes",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Year" : "Año",
    "List" : "Lista",
    "Preview" : "Vista previa",
    "Copy link" : "Copiar enlace",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "Create new" : "Crear nuevo",
    "Calendars" : "Calendarios",
    "New calendar" : "Nuevo calendario",
    "New calendar with task list" : "Nuevo calendario con listado de tareas",
    "Copied link" : "Link copiado",
    "Export" : "Exportar",
    "Empty trash bin" : "Vaciar la papelera",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Deck" : "Deck",
    "Copy internal link" : "Copiar enlace interno",
    "Share link" : "Compartir link",
    "Copy public link" : "Copiar link publico",
    "Copied code" : "Código copiado",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "Save" : "Guardar",
    "View" : "Ver",
    "Filename" : "Nombre de archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "Automatic ({timezone})" : "Automático ({timezone})",
    "Timezone" : "Zona horaria",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "General" : "General",
    "Editing" : "Editando",
    "Files" : "Archivo",
    "Update" : "Actualizar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Visibility" : "Visibilidad",
    "to" : "para",
    "Add" : "Añadir",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Your email address" : "Su dirección de correo electrónico",
    "Back" : "Volver",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "seconds" : "segundos",
    "minutes" : "minutos",
    "hours" : "horas",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
    "Delete file" : "Borrar archivo",
    "Available" : "Disponible",
    "Not available" : "No disponible",
    "Legend" : "Leyenda",
    "Done" : "Terminado",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativo",
    "Attendees" : "Asistentes",
    "Remove group" : "Eliminar grupo",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "first" : "primero",
    "Resources" : "Recursos",
    "available" : "disponible",
    "Yes" : "Sí",
    "None" : "Ninguno",
    "Global" : "Global",
    "Subscribe" : "Suscribirse",
    "Select a date" : "Elija una fecha",
    "Personal" : "Personal",
    "Edit event" : "Editar evento",
    "All day" : "Todo el día",
    "Close" : "Cerrar",
    "30 min" : "30 minutos",
    "Participants" : "Participantes",
    "Submit" : "Enviar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "second" : "segundo",
    "last" : "último",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Categories" : "Categoría",
    "Hidden" : "Oculto",
    "can edit" : "puede editar",
    "Show week numbers" : "Mostrar número de semana"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-calendar-1%3A6.2.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/es_AR.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "La dirección de E Mail proporcionada no es valida",
    "Hello," : "Hola,",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "Location:" : "Ubicación:",
    "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
    "Previous day" : "Día previo",
    "Previous week" : "Semana previa",
    "Previous month" : "Mes previo",
    "Next day" : "Proximo día",
    "Next week" : "Proxima semana",
    "Next month" : "Proximo mes",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Year" : "Año",
    "List" : "Lista",
    "Preview" : "Vista previa",
    "Copy link" : "Copiar enlace",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "Create new" : "Crear nuevo",
    "Copy public link" : "Copiar link publico",
    "Calendars" : "Calendarios",
    "New calendar" : "Nuevo calendario",
    "New calendar with task list" : "Nuevo calendario con listado de tareas",
    "Copied link" : "Link copiado",
    "Export" : "Exportar",
    "Empty trash bin" : "Vaciar la papelera",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Deck" : "Deck",
    "Copy internal link" : "Copiar enlace interno",
    "Share link" : "Compartir link",
    "Copied code" : "Código copiado",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "Save" : "Guardar",
    "View" : "Ver",
    "Filename" : "Nombre de archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "Automatic ({timezone})" : "Automático ({timezone})",
    "Timezone" : "Zona horaria",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "General" : "General",
    "Editing" : "Editando",
    "Files" : "Archivo",
    "Update" : "Actualizar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Visibility" : "Visibilidad",
    "to" : "para",
    "Add" : "Añadir",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Your email address" : "Su dirección de correo electrónico",
    "Back" : "Volver",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "seconds" : "segundos",
    "minutes" : "minutos",
    "hours" : "horas",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
    "Delete file" : "Borrar archivo",
    "Available" : "Disponible",
    "Not available" : "No disponible",
    "Legend" : "Leyenda",
    "Done" : "Terminado",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativo",
    "Copied to clipboard" : "Copiado al portapapeles",
    "Attendees" : "Asistentes",
    "Remove group" : "Eliminar grupo",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "first" : "primero",
    "Resources" : "Recursos",
    "available" : "disponible",
    "Yes" : "Sí",
    "None" : "Ninguno",
    "Global" : "Global",
    "Subscribe" : "Suscribirse",
    "Select a date" : "Elija una fecha",
    "Personal" : "Personal",
    "Edit event" : "Editar evento",
    "All day" : "Todo el día",
    "Close" : "Cerrar",
    "Participants" : "Participantes",
    "Submit" : "Enviar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "second" : "segundo",
    "last" : "último",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Categories" : "Categoría",
    "Hidden" : "Oculto",
    "can edit" : "puede editar",
    "Show week numbers" : "Mostrar número de semana",
    "30 min" : "30 minutos"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
